pygeodesy.ltpTuples.XyzLocal

Package pygeodesy :: Module ltpTuples :: Class XyzLocal |
[frames] | no frames]

# Class XyzLocal

           object --+
                    |
         named._Named --+
                        |
         named._NamedBase --+
                            |
    vector3dBase.Vector3dBase --+
                                |
                vector3d.Vector3d --+
                                    |
                            _Vector3d --+
                                        |
                                       XyzLocal

Known Subclasses:
  - Enu

Local `(x, y, z)` in a local tangent plane (LTP), also base class for local Enu.

Instance Methods
__init__(self, x_xyz, y=0, z=0, ltp=None, **name) New XyzLocal. |
__str__(self) Default `str(self)`. |
classof(self, *args, **kwds) Create another instance of this very class. |
toAer(self, Aer=None, **name_Aer_kwds) Get the local Azimuth, Elevation, slant Range components. |
toCartesian(self, Cartesian=None, ltp=None, **name_Cartesian_kwds) Get the geocentric `(x, y, z)` (ECEF) coordinates of this local. |
toEnu(self, Enu=None, **name_Enu_kwds) Get the local East, North, Up (ENU) components. |
toLatLon(self, LatLon=None, ltp=None, **name_LatLon_kwds) Get the geodetic `(lat, lon, height)` coordinates if this local. |
toLocal9Tuple(self, M=False, **name) Get this local as a `Local9Tuple`. |
toNed(self, Ned=None, **name_Ned_kwds) Get the local North, East, Down (Ned) components. |
toXyz(self, Xyz=None, **name_Xyz_kwds) Get the local X, Y, Z (XYZ) components. |
Inherited from `_Vector3d`: `toRepr`, `toStr` Inherited from `vector3d.Vector3d`: `bearing`, `circin6`, `circum3`, `circum4_`, `iscolinearWith`, `meeus2`, `nearestOn`, `nearestOn6`, `parse`, `radii11`, `soddy4`, `trilaterate2d2`, `trilaterate3d2` Inherited from `vector3dBase.Vector3dBase`: `__abs__`, `__add__`, `__bool__`, `__ceil__`, `__cmp__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floor__`, `__floordiv__`, `__ge__`, `__gt__`, `__hash__`, `__iadd__`, `__idiv__`, `__ifloordiv__`, `__imatmul__`, `__imod__`, `__imul__`, `__int__`, `__ipow__`, `__isub__`, `__itruediv__`, `__le__`, `__long__`, `__lt__`, `__matmul__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmatmul__`, `__rmod__`, `__rmul__`, `__round__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__sub__`, `__truediv__`, `__trunc__`, `angleTo`, `apply`, `bools`, `cmp`, `cross`, `dividedBy`, `dividedBy_`, `dot`, `equals`, `equirectangular`, `fabs`, `floats`, `floorDividedBy`, `floorDividedBy_`, `intermediateTo`, `ints`, `isconjugateTo`, `isequalTo`, `minus`, `minus_`, `negate`, `others`, `plus`, `plus_`, `pow`, `rotate`, `rotateAround`, `sum`, `times`, `times_`, `to3xyz`, `unit` Inherited from `named._NamedBase`: `__repr__` Inherited from `named._Named`: `__format__`, `attrs`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| aer4 Get the `(azimuth, elevation, slantrange, ltp)` components (Aer4Tuple).
| azimuth Get the Azimuth, bearing from North (`degrees360`).
| down Get the Down component (`meter`).
| ecef Get this LTP's ECEF converter (`Ecef...` instance).
| east Get the East component (`meter`).
| elevation Get the Elevation, tilt above horizon (`degrees90`).
| enu4 Get the `(east, north, up, ltp)` components (Enu4Tuple).
| groundrange Get the ground range, distance (`meter`).
| ltp Get the local tangent plane (Ltp).
| ned4 Get the `(north, east, down, ltp)` components (Ned4Tuple).
| north Get the North component (`meter`).
| slantrange Get the slant Range, distance (`meter`).
| up Get the Up component (`meter`).
| xyz4 Get the `(x, y, z, ltp)` components (Xyz4Tuple).
| xyzLocal Get this XyzLocal.
Inherited from `vector3dBase.Vector3dBase`: `crosserrors`, `euclid`, `homogeneous`, `length`, `length2`, `x`, `x2y2z2`, `x2y2z23`, `xyz`, `xyz3`, `y`, `z` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, x_xyz, y=0, z=0, ltp=None, **name) (Constructor) |
New XyzLocal. Arguments: `x_xyz` - Scalar X component (`meter`), `positive east` or a previous local instance (XyzLocal, Xyz4Tuple, Aer, Aer4Tuple, Enu, Enu4Tuple, Local9Tuple, Ned or Ned4Tuple). `y` - Scalar Y component (`meter`), only used with scalar `x_xyz`, `positive north`. `z` - Scalar Z component, normal `positive up` from the surface of the ellipsoid or sphere (`meter`), only used with scalar `x_xyz`. `ltp` - The local tangent plane, (geodetic) origin (Ltp, LocalCartesian). `name` - Optional `name=NN` (`str`). Raises: `TypeError` - Invalid `x_xyz` or `ltp`. `UnitError` - Invalid scalar `x_xyz`, `y` or `z`. Overrides: object.__init__

### __str__ (self) (Informal representation operator) |
Default `str(self)`. Overrides: object.__str__ (inherited documentation)

### classof (self, *args, **kwds) |
Create another instance of this very class. Arguments: `args` - Optional, positional arguments. `kwds` - Optional, keyword arguments. Returns: New instance (`self.__class__`). Overrides: named._Named.classof

### toAer (self, Aer=None, **name_Aer_kwds) |
Get the local Azimuth, Elevation, slant Range components. Arguments: `Aer` - Class to return AER (Aer) or `None`. `name_Aer_kwds` - Optional `name=NN` (`str`) and optionally, additional `Aer` keyword arguments, ignored if `Aer is None`. Returns: An `Aer` instance or an Aer4Tuple`(azimuth, elevation, slantrange, ltp)` if `Aer is None`. Raises: `TypeError` - Invalid `Aer` or `name_Aer_kwds` item.

### toCartesian (self, Cartesian=None, ltp=None, **name_Cartesian_kwds) |
Get the geocentric `(x, y, z)` (ECEF) coordinates of this local. Arguments: `Cartesian` - Optional class to return `(x, y, z)` (`Cartesian`) or `None`. `ltp` - Optional local tangent plane (LTP) (Ltp), overriding this `ltp`. `name_Cartesian_kwds` - Optional `name=NN` (`str`) and optionally, additional `Cartesian` keyword arguments, ignored if `Cartesian is None`. Returns: A `Cartesian` instance or if `Cartesian is None`, an Ecef9Tuple`(x, y, z, lat, lon, height, C, M, datum)` with `M=None`, always. Raises: `TypeError` - Invalid `ltp`, `Cartesian` or `name_Cartesian_kwds` item. Overrides: vector3d.Vector3d.toCartesian

### toEnu (self, Enu=None, **name_Enu_kwds) |
Get the local East, North, Up (ENU) components. Arguments: `Enu` - Class to return ENU (Enu) or `None`. `name_Enu_kwds` - Optional `name=NN` (`str`) and optionally, additional `Enu` keyword arguments, ignored if `Enu is None`. Returns: An `Enu` instance or an Enu4Tuple`(east, north, up, ltp)` if `Enu is None`. Raises: `TypeError` - Invalid `Enu` or `name_Enu_kwds` item.

### toLatLon (self, LatLon=None, ltp=None, **name_LatLon_kwds) |
Get the geodetic `(lat, lon, height)` coordinates if this local. Arguments: `LatLon` - Optional class to return `(x, y, z)` (`LatLon`) or `None`. `ltp` - Optional local tangent plane (LTP) (Ltp), overriding this ENU/NED/AER/XYZ's LTP. `name_LatLon_kwds` - Optional `name=NN` (`str`) and optionally, additional `LatLon` keyword arguments, ignored if `LatLon is None`. Returns: An `LatLon` instance or an Ecef9Tuple`(x, y, z, lat, lon, height, C, M, datum)` if `LatLon is None`, with `M=None`. Raises: `TypeError` - Invalid `LatLon`, `ltp` or `name_LatLon_kwds` item.

### toLocal9Tuple (self, M=False, **name) |
Get this local as a `Local9Tuple`. Arguments: `M` - Optionally include the rotation matrix (`bool`). `name` - Optional `name=NN` (`str`). Returns: Local9Tuple`(x, y, z, lat, lon, height, ltp, ecef, M)` with `ltp` this `Ltp`, `ecef` an Ecef9Tuple and `M` an EcefMatrix or `None`.

### toNed (self, Ned=None, **name_Ned_kwds) |
Get the local North, East, Down (Ned) components. Arguments: `Ned` - Class to return NED (Ned) or `None`. `name_Ned_kwds` - Optional `name=NN` (`str`) and optionally, additional `Ned` keyword arguments, ignored if `Ned is None`. Returns: An `Ned` instance or an Ned4Tuple`(north, east, down, ltp)` if `Ned is None`. Raises: `TypeError` - Invalid `Ned` or `name_Ned_kwds` item.

### toXyz (self, Xyz=None, **name_Xyz_kwds) |
Get the local X, Y, Z (XYZ) components. Arguments: `Xyz` - Class to return XYZ (XyzLocal, Enu, Ned, Aer) or `None`. `name_Xyz_kwds` - Optional `name=NN` (`str`) and optionally, additional `Xyz` keyword arguments, ignored if `Xyz is None`. Returns: An `Xyz` instance or an Xyz4Tuple`(x, y, z, ltp)` if `Xyz is None`. Raises: `TypeError` - Invalid `Xyz` or `name_Xyz_kwds` item.

Property Details

### aer4 Get the `(azimuth, elevation, slantrange, ltp)` components (Aer4Tuple). Get method: aer4(self) - Get the `(azimuth, elevation, slantrange, ltp)` components (Aer4Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### azimuth Get the Azimuth, bearing from North (`degrees360`). Get method: azimuth(self) - Get the Azimuth, bearing from North (`degrees360`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Azimuth.

### down Get the Down component (`meter`). Get method: down(self) - Get the Down component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### ecef Get this LTP's ECEF converter (`Ecef...` instance). Get method: ecef(self) - Get this LTP's ECEF converter (`Ecef...` instance). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### east Get the East component (`meter`). Get method: east(self) - Get the East component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### elevation Get the Elevation, tilt above horizon (`degrees90`). Get method: elevation(self) - Get the Elevation, tilt above horizon (`degrees90`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Elevation.

### enu4 Get the `(east, north, up, ltp)` components (Enu4Tuple). Get method: enu4(self) - Get the `(east, north, up, ltp)` components (Enu4Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### groundrange Get the ground range, distance (`meter`). Get method: groundrange(self) - Get the ground range, distance (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### ltp Get the local tangent plane (Ltp). Get method: ltp(self) - Get the local tangent plane (Ltp). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### ned4 Get the `(north, east, down, ltp)` components (Ned4Tuple). Get method: ned4(self) - Get the `(north, east, down, ltp)` components (Ned4Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### north Get the North component (`meter`). Get method: north(self) - Get the North component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### slantrange Get the slant Range, distance (`meter`). Get method: slantrange(self) - Get the slant Range, distance (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### up Get the Up component (`meter`). Get method: up(self) - Get the Up component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyz4 Get the `(x, y, z, ltp)` components (Xyz4Tuple). Get method: xyz4(self) - Get the `(x, y, z, ltp)` components (Xyz4Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyzLocal Get this XyzLocal. Get method: xyzLocal(self) - Get this XyzLocal. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.